OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "El operador indicado es inválido",
    "The given regular expression is invalid" : "La expresión regular indicada es inválida",
    "The given file size is invalid" : "El tamaño de archivo indicado es inválido",
    "The given tag id is invalid" : "El id de la etiqueta es inválido",
    "The given IP range is invalid" : "El rango de IP's es inválido",
    "The given IP range is not valid for IPv4" : "El rango de IPs dado no es válido para IPv4",
    "The given IP range is not valid for IPv6" : "El rango de IPs dado no es válido para IPv6",
    "The given time span is invalid" : "El espacio de tiempo dado es inválido",
    "The given start time is invalid" : "El tiempo inicial dado no es válido",
    "The given end time is invalid" : "El tiempo final dado no es válido",
    "The given group does not exist" : "El grupo dado no existe",
    "File" : "Archivo",
    "File created" : "Archivo creado",
    "File updated" : "Archivo actualizado",
    "File renamed" : "Archivo renombrado",
    "File deleted" : "Archivo eliminado",
    "File accessed" : "Archivo accedido",
    "File copied" : "Archivo copiado",
    "Tag assigned" : "Etiqueta asignada",
    "Someone" : "Alguien",
    "%s created %s" : "%s ha creado %s",
    "%s modified %s" : "%s ha modificado %s",
    "%s deleted %s" : "%s ha eliminado %s",
    "%s accessed %s" : "%s ha accedido a %s",
    "%s renamed %s" : "%s ha renombrado %s",
    "%s copied %s" : "%s ha copiado %s",
    "%s assigned %s to %s" : "%s ha asignado %s a %s",
    "Operation #%s does not exist" : "La operación #%s  no existe",
    "Entity %s does not exist" : "La entidad %s no existe",
    "Entity %s is invalid" : "La entidad %s no es válida",
    "No events are chosen." : "No se han elegido eventos.",
    "Entity %s has no event %s" : "La entidad %s no tiene evento %s",
    "Operation %s does not exist" : "La operación %s no existe",
    "Operation %s is invalid" : "La operación %s es inválida",
    "At least one check needs to be provided" : "Se debe proporcionar al menos una comprobación",
    "The provided operation data is too long" : "Los datos de operación proporcionados son demasiado largos",
    "Invalid check provided" : "La comprobación proporcionada no es válida",
    "Check %s does not exist" : "La validación %s no existe",
    "Check %s is invalid" : "La validación %s no es inválida",
    "Check %s is not allowed with this entity" : "La comprobación %s no se permite con esta entidad",
    "The provided check value is too long" : "El valor de comprobación proporcionado es demasiado largo",
    "Check #%s does not exist" : "La validación #%s no existe",
    "Check %s is invalid or does not exist" : "La validación %s es inválida o no existe",
    "Flow" : "Flujo",
    "Nextcloud workflow engine" : "Motor de flujo de trabajo de Nextcloud",
    "Select a filter" : "Seleccionar un filtro",
    "Select a comparator" : "Seleccionar un comparador",
    "Remove filter" : "Quitar filtro",
    "Audio" : "Audio",
    "Folder" : "Carpeta",
    "Images" : "Imágenes",
    "Office documents" : "Documentos de oficina",
    "PDF documents" : "Documentos PDF",
    "Video" : "Video",
    "Custom MIME type" : "Tipo de MIME personalizado",
    "Custom mimetype" : "mimetype personalizado",
    "Select a file type" : "Seleccionar un tipo de archivo",
    "e.g. httpd/unix-directory" : "p. ej. httpd/unix-directory",
    "Please enter a valid time span" : "Por favor introduzca un período de tiempo válido",
    "Files WebDAV" : "Archivos WebDAV",
    "Custom URL" : "URL personalizada",
    "Select a request URL" : "Seleccionar una URL de solicitud",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de escritorio",
    "Thunderbird & Outlook addons" : "Complementos de Thunderbird y Outlook",
    "Custom user agent" : "Agente de usuario personalizado",
    "Select a user agent" : "Seleccionar un agente de usuario",
    "Select groups" : "Seleccionar grupos",
    "Groups" : "Grupos",
    "Select a trigger" : "Seleccionar un desencadenante",
    "At least one event must be selected" : "Debe seleccionar al menos un evento",
    "Add new flow" : "Añadir nuevo flujo",
    "The configuration is invalid" : "La configuración no es válida",
    "Active" : "Activo",
    "Save" : "Guardar",
    "When" : "Cuando",
    "and" : "y",
    "Add a new filter" : "Añadir un nuevo filtro",
    "Cancel" : "Cancelar",
    "Delete" : "Eliminar",
    "Available flows" : "Flujos disponibles",
    "For details on how to write your own flow, check out the development documentation." : "Para obtener detalles sobre cómo escribir su propio flujo, consulte la documentación de desarrollo.",
    "No flows installed" : "No hay flujos instalados",
    "Ask your administrator to install new flows." : "Pida a su administrador instalar nuevos flujos.",
    "More flows" : "Más flujos",
    "Browse the App Store" : "Explorar la tienda de aplicaciones",
    "Show less" : "Mostrar menos",
    "Show more" : "Mostrar más",
    "Configured flows" : "Flujos configurados",
    "Your flows" : "Sus flujos",
    "No flows configured" : "No hay flujos configurados",
    "matches" : "coincide",
    "does not match" : "No coincide",
    "is" : "es",
    "is not" : "no es",
    "File name" : "Nombre de archivo",
    "File MIME type" : "Tipo MIME del archivo",
    "File size (upload)" : "Tamaño del archivo (carga)",
    "less" : "menos",
    "less or equals" : "menos o igual",
    "greater or equals" : "mayor o igual",
    "greater" : "mayor",
    "Request remote address" : "Solicitar dirección remota",
    "matches IPv4" : "coincide con IPv4",
    "does not match IPv4" : "no coincide con IPv4",
    "matches IPv6" : "coincide con IPv6",
    "does not match IPv6" : "no coincide con IPv6",
    "File system tag" : "Etiqueta del sistema de archivos",
    "is tagged with" : "está etiquetado con",
    "is not tagged with" : "no está etiquetado con",
    "Request URL" : "Solicitar URL",
    "Request time" : "Tiempo de la solicitud",
    "between" : "entre",
    "not between" : "no entre",
    "Request user agent" : "Solicitar agente de usuario",
    "Group membership" : "Membresía a grupos",
    "is member of" : "es miembro de",
    "is not member of" : "no es miembro de",
    "Type to search for group …" : "Escriba para seleccionar un grupo..."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
